pub enum VecInterpolateError<E> {
MismatchedLength,
Inner(E),
}Expand description
Errors produced when interpolating dynamically-sized arrays
Variants
MismatchedLength
Produced when arrays to be interpolated are of different lengths
Inner(E)
Produced when an error occurs interpolating an array element